@@ -1,12 +1,12 @@
 ;;; images.el --- Automatic image converters
-;; Author: wmperry
-;; Created: 1998/12/18 02:19:27
-;; Version: 1.1.1.2
+;; Author: $Author: legoscia $
+;; Created: $Date: 2007/11/15 12:22:34 $
+;; Version: $Revision: 1.6 $
 ;; Keywords: images
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;; Copyright (c) 1996 - 1999, 2007 Free Software Foundation Inc.
 ;;; Copyright (c) 1995 - 1996 by William M. Perry <wmperry@cs.indiana.edu>
-;;; Copyright (c) 1996 - 1999 Free Software Foundation Inc.
 ;;;
 ;;; This file is part of GNU Emacs.
 ;;;
@@ -26,23 +26,17 @@
 ;;; Boston, MA 02111-1307, USA.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;; The emacsen compatibility package - load it up before anything else
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-(require 'mule-sysdp)
-
-(eval-and-compile
-  (if (not (and (string-match "XEmacs" emacs-version)
-		(or (> emacs-major-version 19)
-		    (>= emacs-minor-version 14))))
-      (require 'w3-sysdp)))
-
 (defvar image-temp-stack nil "Do no touch - internal storage.")
 (defvar image-converters nil "Storage for the image converters.")
 (defvar image-native-formats
-  (delq nil (cons (if (featurep 'x) 'xbm)
-		  (mapcar (function (lambda (x) (if (featurep x) x)))
-			  '(xpm gif jpeg tiff png imagick))))
+  (cond
+   ((featurep 'xemacs)
+    (delq nil (cons (if (featurep 'x) 'xbm)
+		    (mapcar (function (lambda (x) (if (featurep x) x)))
+			    '(xpm gif jpeg tiff png imagick)))))
+   ((boundp 'image-types)
+    image-types)
+   (t nil))
   "A list of image formats that this version of emacs supports natively.")
 
 (defun image-register-converter (from to converter)
@@ -151,7 +145,7 @@ to a suitable internal image format will be carried out."
 	      (while chain
 		(cond
 		 ((stringp (car chain))
-		  (let ((file-coding-system mule-no-coding-system))
+		  (let ((coding-system-for-read 'binary))
 		    (call-process-region
 		     (point-min) (point-max)
 		     shell-file-name t
@@ -175,7 +169,7 @@ to a suitable internal image format will be carried out."
     (image-register-converter 'pgm 'pbm "pgmtopbm")
     (image-register-converter 'ppm 'pgm "ppmtopgm")
     (image-register-converter 'pnm 'xpm "ppmtoxpm")
-    (image-register-converter 'ppm 'xpm "ppmtoxpm)")
+    (image-register-converter 'ppm 'xpm "ppmtoxpm")
     (image-register-converter 'xpm 'ppm "xpmtoppm")
     (image-register-converter 'gif 'ppm "giftopnm")
     (image-register-converter 'pnm 'gif "(ppmquant 256 | ppmtogif)")
